var indexSectionsWithContent =
{
  0: "02_abcdefghilmnoprstuvwx",
  1: "b",
  2: "bl",
  3: "b",
  4: "abcdfhilmnoprstuvx",
  5: "b",
  6: "b",
  7: "bc",
  8: "ac",
  9: "abcdefgilmoprstvw",
  10: "02bcdefilmnrstuvw"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "files",
  3: "functions",
  4: "variables",
  5: "typedefs",
  6: "enums",
  7: "enumvalues",
  8: "defines",
  9: "groups",
  10: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Data Structures",
  2: "Files",
  3: "Functions",
  4: "Variables",
  5: "Typedefs",
  6: "Enumerations",
  7: "Enumerator",
  8: "Macros",
  9: "Modules",
  10: "Pages"
};

